function par = exp_config_roex(npar, siglev_spl, fo)
    
    % Model settings
    par.model = 'roex'; % Model name. Currently, only roex model is supported.
    par.npar = npar;    % The number of parameters.
    par.pf_par.gamma = 1/3; % Expected chance performance (e.g., 1/3 for a 3AFC task).
    par.pf_par.beta = 1;    % Assumed slope of the psychometric function, not crucial.
    
    % Stimulus settings
    par.stim_par.fo = fo; % Signal frequency
    par.stim_par.siglev = siglev_spl;   % Signal level in dB SPL
    par.stim_par.BW = 0.25*par.stim_par.fo;      % Masker bandwidth in Hz
    
    if npar == 5
        % Stimulus space
        par.x_lim = [0 0 -10;0.4 0.6 55];    % The three columns are for gu, gl, and masker level
        par.x_n = [3 13 20];    % The number of points along the three stimulus axis.

        % Priors
        par.prior_phi = [40; 40; 5; -30; 5];    % Means
        par.prior_P = diag([40 40 5 40 20].^2); % Covariance matrix

    elseif npar == 4
        % Stimulus space
        par.x_lim = [0 0 -10;0.4 0.6 55];    % the three columns are for gu, gl, and masker level
        par.x_n = [3 13 20];    % The number of points along the three stimulus axis.

        % Priors
        par.prior_phi = [40; 40; -30; 5];       % Means
        par.prior_P = diag([40 40 40 20].^2);   % Covariance matrix

    elseif npar == 3
        % Stimulus space
        par.x_lim = [0 0 -10;0.4 0.6 55];    % the three columns are for gu, gl, and masker level
        par.x_n = [3 13 20];    % The number of points along the three stimulus axis.

        % Priors
        par.prior_phi = [40; -30; 5];       % Means
        par.prior_P = diag([40 40 20].^2);  % Covariance matrix
    end
end

%eof